'use strict';

var grammarJsonWithComments = require('@codemovie/grammar-json-with-comments');
var language = require('@codemirror/language');

/// A language provider that provides JSON parsing.
const jsoncLanguage = language.LRLanguage.define({
    name: "jsonc",
    parser: grammarJsonWithComments.parser.configure({
        props: [
            language.indentNodeProp.add({
                Object: language.continuedIndent({ except: /^\s*\}/ }),
                Array: language.continuedIndent({ except: /^\s*\]/ })
            }),
            language.foldNodeProp.add({
                "Object Array": language.foldInside
            })
        ]
    }),
    languageData: {
        closeBrackets: { brackets: ["[", "{", '"'] },
        indentOnInput: /^\s*[\}\]]$/
    }
});
/// JSONC language support.
function jsonc() {
    return new language.LanguageSupport(jsoncLanguage);
}

exports.jsonc = jsonc;
exports.jsoncLanguage = jsoncLanguage;
