import { parser } from '@codemovie/grammar-json-with-comments';
import { LRLanguage, indentNodeProp, foldNodeProp, continuedIndent, foldInside, LanguageSupport } from '@codemirror/language';

/// A language provider that provides JSON parsing.
const jsoncLanguage = /*@__PURE__*/LRLanguage.define({
    name: "jsonc",
    parser: /*@__PURE__*/parser.configure({
        props: [
            /*@__PURE__*/indentNodeProp.add({
                Object: /*@__PURE__*/continuedIndent({ except: /^\s*\}/ }),
                Array: /*@__PURE__*/continuedIndent({ except: /^\s*\]/ })
            }),
            /*@__PURE__*/foldNodeProp.add({
                "Object Array": foldInside
            })
        ]
    }),
    languageData: {
        closeBrackets: { brackets: ["[", "{", '"'] },
        indentOnInput: /^\s*[\}\]]$/
    }
});
/// JSONC language support.
function jsonc() {
    return new LanguageSupport(jsoncLanguage);
}

export { jsonc, jsoncLanguage };
